@@ -138,15 +138,11 @@ class System():
 
     async def a_update(self):
         last_update = time()
-        print('system %s is alive: %s' % (self.type, self.alive))
         while self.alive:
-            print('update %s' % self.type)
             new_update = time()
             if iscoroutinefunction(self.update):
-                print('update %s is awaitable' % self.type)
                 await self.update(new_update-last_update)
             else:
-                print('update %s is not awaitable' % self.type)
                 self.update(new_update-last_update)
 
             last_update = new_update
